@@ -6,7 +6,7 @@ use warnings;
 use Scalar::Util qw/reftype/;
 use Text::Wrap qw/wrap/;
 
-our $VERSION = '0.23';
+our $VERSION = '0.24';
 our @ISA;
 
 require Exporter;
@@ -69,14 +69,13 @@ following can expand out to include the desired Dumper routine:
 
 =head1 AUTHOR
 
-Jeremy Mates, E<lt>jmates@cpan.orgE<gt>
+thrig - Jeremy Mates (cpan:JMATES) C<< <jmates at cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2013 by Jeremy Mates
+Copyright (C) 2013,2015 by Jeremy Mates
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.16.1 or,
-at your option, any later version of Perl 5 you may have available.
+This module is free software; you can redistribute it and/or modify it
+under the Artistic License (2.0).
 
 =cut
